==> plugin-share-session-1.3.7-20180626.035544-1-sources.jar: com/ohaotian/plugin/session/CacheSessionRepository.java <==
package com.ohaotian.plugin.session;

import com.ohaotian.plugin.cache.CacheTemplate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.session.SessionRepository;
import org.springframework.session.web.http.DefaultCookieSerializer;

public class CacheSessionRepository implements SessionRepository<CacheSession> {


    private final static Logger logger = LoggerFactory.getLogger(CacheSessionRepository.class);



    private CacheTemplate cacheTemplate = CacheTemplate.getIstance();
    
    private final static String REGION = "ZT-SESSIONID";

    @Override
    public CacheSession createSession() {
        CacheSession session = new CacheSession();
        return session;
    }

    @Override
    public void save(CacheSession session) {
        if (session == null)
            return;
        if (session.isNew()) {
            session.setNew(false);
            cacheTemplate.set(getSessionId(session.getId()), session);
        }
    }

    @Override
    public CacheSession getSession(String id) {
        Object o = cacheTemplate.get(getSessionId(id));
        if(o instanceof  CacheSession){
            CacheSession session = (CacheSession) o;
            logger.info(o.toString());
            logger.info(session.getCreationTime() + " " + session.getLastAccessedTime() + " " + session.getCreationTime());
            return session;
        }
            return null;

    }

    @Override
    public void delete(String id) {
        CacheSession session = getSession(id);
        if (session == null)
            return;
        cacheTemplate.del(getSessionId(id));
    }

    private String getSessionId(String id){
        return REGION+":"+id;
    }


}

==> plugin-share-session-2.0.11-20200909.070850-6-sources.jar: com/ohaotian/plugin/session/CacheSessionRepository.java <==
package com.ohaotian.plugin.session;

import com.ohaotian.plugin.cache.CacheTemplate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.session.SessionRepository;

/**
 * @author liubq
 */
public class CacheSessionRepository implements SessionRepository<CacheSession> {

    private final static Logger log = LoggerFactory.getLogger(CacheSessionRepository.class);


    private CacheTemplate cacheTemplate = CacheTemplate.getIstance();

    private final static String REGION = "ZT-SESSIONID";

    @Override
    public CacheSession createSession() {
        CacheSession session = new CacheSession();
        return session;
    }

    @Override
    public void save(CacheSession session) {
        if (session == null){
            return;
        }
        if (session.isNew()) {
            session.setNew(false);
            cacheTemplate.set(getSessionId(session.getId()), session);
        }
    }

    @Override
    public CacheSession findById(String id) {
        log.info("ZTSESSIONID:{}",id);
        Object o = cacheTemplate.get(getSessionId(id));
        if (o instanceof CacheSession) {
            CacheSession session = (CacheSession) o;
            log.info(o.toString());
            log.info(session.getCreationTime() + " " + session.getLastAccessedTime() + " " + session.getCreationTime());
            return session;
        }
        return null;
    }

    @Override
    public void deleteById(String id) {
        CacheSession session = findById(id);
        if (session == null){
            return;
        }
        cacheTemplate.del(getSessionId(id));
    }


    private String getSessionId(String id) {
        return REGION + ":" + id;
    }


}
